==> telegrambots-0.0.3rc0.tar.gz: telegrambots-0.0.3rc0/src/telegrambots/wrapper/types/objects/file.py <==
from dataclasses import dataclass, field
from typing import Optional

from ...._client_utilities import ClientTargetable
from ..api_object import TelegramBotsObject




@dataclass(init=True, repr=True, slots=True)
class File(TelegramBotsObject, ClientTargetable):
    # --- description here ---
    """This object represents a file ready to be downloaded. The file can be downloaded via the link `https://api.telegram.org/file/bot<token>/<file_path>`. It is guaranteed that the link will be valid for at least 1 hour. When the link expires, a new one can be requested by calling [getFile](https://core.telegram.org/bots/api/#getfile).
    
    Maximum file size to download is 20 MB
    
    More info at: https://core.telegram.org/bots/api/#file
    """

    # --- properties here ---
    file_id: str = field(metadata={"ac_type": [str], "ac_name": "file_id"})
    """Identifier for this file, which can be used to download or reuse the file
    """

    file_unique_id: str = field(metadata={"ac_type": [str], "ac_name": "file_unique_id"})
    """Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
    """

    file_size: Optional[int] = field(default=None, metadata={"ac_type": [int], "ac_name": "file_size"})
    """*Optional*. File size in bytes, if known
    """

    file_path: Optional[str] = field(default=None, metadata={"ac_type": [str], "ac_name": "file_path"})
    """*Optional*. File path. Use `https://api.telegram.org/file/bot<token>/<file_path>` to get the file.
    """

==> telegrambots-0.0.9rc0.tar.gz: telegrambots-0.0.9rc0/src/telegrambots/wrapper/types/objects/file.py <==
from dataclasses import dataclass, field
from typing import Optional

from ..._client_utilities import ClientTargetable
from ..api_object import TelegramBotsObject


@dataclass(init=True, repr=True, slots=True)
class File(TelegramBotsObject, ClientTargetable):
    # --- description here ---
    """This object represents a file ready to be downloaded. The file can be downloaded via the link `https://api.telegram.org/file/bot<token>/<file_path>`. It is guaranteed that the link will be valid for at least 1 hour. When the link expires, a new one can be requested by calling [getFile](https://core.telegram.org/bots/api/#getfile).

    Maximum file size to download is 20 MB

    More info at: https://core.telegram.org/bots/api/#file
    """

    # --- properties here ---
    file_id: str = field(metadata={"ac_type": [str], "ac_name": "file_id"})
    """Identifier for this file, which can be used to download or reuse the file
    """

    file_unique_id: str = field(
        metadata={"ac_type": [str], "ac_name": "file_unique_id"}
    )
    """Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
    """

    file_size: Optional[int] = field(
        default=None, metadata={"ac_type": [int], "ac_name": "file_size"}
    )
    """*Optional*. File size in bytes, if known
    """

    file_path: Optional[str] = field(
        default=None, metadata={"ac_type": [str], "ac_name": "file_path"}
    )
    """*Optional*. File path. Use `https://api.telegram.org/file/bot<token>/<file_path>` to get the file.
    """
